@@ -8,6 +8,7 @@ import {
   PipelineRunInlineResourceParam,
   PipelineRunReferenceResource,
   PipelineRunResource,
+  PipelineWorkspace,
 } from '../../../../utils/pipeline-augment';
 import { PipelineRunModel } from '../../../../models';
 import { getPipelineRunParams, getPipelineRunWorkspaces } from '../../../../utils/pipeline-utils';
@@ -118,6 +119,11 @@ export const convertPipelineToModalData = (
         type: resource.type,
       },
     })),
+    workspaces: (pipeline.spec.workspaces || []).map((workspace: PipelineWorkspace) => ({
+      ...workspace,
+      type: 'EmptyDirectory',
+      data: { emptyDir: {} },
+    })),
   };
 };
 
