@@ -2,7 +2,7 @@ import { k8sCreate, K8sResourceKind } from '@console/internal/module/k8s';
 import { VMKind } from '../../../types/vm';
 import { VirtualMachineModel } from '../../../models';
 import { CloneTo, VMClone } from '../../helpers/vm-clone';
-import { isVMRunning } from '../../../selectors/vm';
+import { isVMExpectedRunning } from '../../../selectors/vm';
 import { stopVM } from './actions';
 
 type CloneFrom = {
@@ -15,7 +15,7 @@ export const cloneVM = async (
   { vm, persistentVolumeClaims, dataVolumes }: CloneFrom,
   cloneTo: CloneTo,
 ) => {
-  if (isVMRunning(vm)) {
+  if (isVMExpectedRunning(vm)) {
     await stopVM(vm);
   }
 
